clc;
clear;

format long g
%number of man days per hectare for each crop
man_days_per_hectare = [0 0 5 5 9 2 1.5 2 1 26 12 0;
    0 0 0 0 4.3 5.04 7.16 7.97 4.41 1.12 0 0;
    5.16 5 19.6 2.42 0 0 0 0 0 0 11.2 4.68;
    0.75 0.75 0.75 16 0 0 0 0 0 0 7.5 0.75];

%constant parameters like unit yield, cost, revenue family labor available,
%and other costs and prices
yield_per_hectare = [1.5 2 3 1];
cost_per_hectare = [80 5 50 5];
price_per_ton = [350 70 125 200];
labor_hire_cost = 4;
off_farm_work = 3;
labor_limit = 25;
%--------------------------------------------------------------------------
%LINPROG solver
% [x,fval]=linprog(f,A,b,Aeq,beq,lb,ub)
% this function solves the following linear programming problem
%   min f*x
%  subject to
%        A*x <=b
%        Aeq * x = beq   
%        lb <= x <= ub
% the return variables are :
% x : the solution
% fval: value of the objective function at the optimal solution
%--------------------------------------------------------------------------
%defining the input matrices of linprog()
%The problem is formulated with 48 decision variables
%DECISION VARIABLES: 
% x1_1,x1_2,x1_3,x1_4,x2_1,x2_2,x2_3................x12_1,x12_2,x12_3,x12_4
% of the form x<month_number>_<crop_number>
%OBJECTIVE FUNCTION:
% sum of([price_per_ton(j)*yield_per_hectare(j)- cost_per_hectare(j)]*xi_j) 
% for month i and crop j 
%INEQUALITY CONSTRAINTS:
% Example: 5.16*x1_3 + 0.75*x1_4 <= 31 (number of days in january)
% A is coefficient matrix of Inequality constraints
%EQUALITY CONSTRAINTS:
% Example: x1_1 = 0, x1_2 = 0 etc (rice in jan is zero, maize in jan is zero
% Lower limit = 0
%--------------------------------------------------------------------------

A(24,48) = 0;
Atemp = transpose(man_days_per_hectare);
Btemp = [31;
    28;
    31;
    30;
    31;
    30;
    31;
    31;
    30;
    31;
    30;
    31];
B(24,1) = 0;
for i = 1:12
    for j = 1:4
        A(i,j+4*(i-1)) = Atemp(i,j);
        A(12+i,j+4*(i-1)) = 1;
    end
    B(i,1) = Btemp(i,1);
    B(12+i,1) = 4;
end
Aeq(12,48) = 0;
Beq(12,1) = 0;
Aeq(1,1) = 1;
Aeq(1,2) = 1;
Aeq(2,5) = 1;
Aeq(2,6) = 1;
Aeq(3,10) = 1;
Aeq(4,14) = 1;
Aeq(5,19) = 1;
Aeq(5,20) = 1;
Aeq(6,23) = 1;
Aeq(6,24) = 1;
Aeq(7,27) = 1;
Aeq(7,28) = 1;
Aeq(8,31) = 1;
Aeq(8,32) = 1;
Aeq(9,35) = 1;
Aeq(9,36) = 1;
Aeq(10,39) = 1;
Aeq(10,40) = 1;
Aeq(11,42) = 1;
Aeq(12,45) = 1;
Aeq(12,46) = 1;

for i = 1:12
    Beq(i,1) = 0;
end
f(1,48) = 0;
for i = 1:4
    f(i) = price_per_ton(i)*yield_per_hectare(i) - cost_per_hectare(i);
    
end
for i = 1:48
    if rem(i,4) == 0
        f(1,i) = f(1,4);
    else
        f(1,i) = f(1,rem(i,4));
    end
end

lb = zeros(1,48);

[x,fval] = linprog(-f,A,B,Aeq,Beq,lb);
Ndecimals = 10 ;
f = 10.^Ndecimals; 
x = round(f*x)/f

for i = 1:12
    number_of_days_used(i,1) = A(i,:)*x;
    number_hectacres_used(i,1) = A(12+i,:)*x;
end
Ndecimals = 3 ;
f = 10.^Ndecimals; 
number_of_days_used = round(f*number_of_days_used)/f
number_hectacres_used = round(f*number_hectacres_used)/f



Total_Revenue = fval;
for i = 1:12
    if number_of_days_used(i) > labor_limit
        Total_Revenue = - Total_Revenue + labor_hire_cost*(number_of_days_used(i)-labor_limit);
    else
        Total_Revenue = -fval +off_farm_work*(labor_limit - number_of_days_used(i));
    end
end

Total_Revenue = round(f*Total_Revenue)/f
